Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(14)

Unified Diff: net/url_request/url_request_job_tracker.h

Issue 3010037: Add the actual data being read to the OnBytesRead callback, take two.... (Closed) Base URL: http://src.chromium.org/svn/trunk/src/
Patch Set: '' Created 10 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/url_request/url_request_job.cc ('k') | net/url_request/url_request_job_tracker.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/url_request/url_request_job_tracker.h
===================================================================
--- net/url_request/url_request_job_tracker.h (revision 55065)
+++ net/url_request/url_request_job_tracker.h (working copy)
@@ -1,4 +1,4 @@
-// Copyright (c) 2006-2008 The Chromium Authors. All rights reserved.
+// Copyright (c) 2010 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -44,9 +44,13 @@
virtual void OnJobRedirect(URLRequestJob* job, const GURL& location,
int status_code) = 0;
- // Called when a new chunk of bytes has been read for the given job. The
- // byte count is the number of bytes for that read event only.
- virtual void OnBytesRead(URLRequestJob* job, int byte_count) = 0;
+ // Called when a new chunk of unfiltered bytes has been read for
+ // the given job. |byte_count| is the number of bytes for that
+ // read event only. |buf| is a pointer to the data buffer that
+ // contains those bytes. The data in |buf| is only valid for the
+ // duration of the OnBytesRead callback.
+ virtual void OnBytesRead(URLRequestJob* job, const char* buf,
+ int byte_count) = 0;
virtual ~JobObserver() {}
};
@@ -75,7 +79,7 @@
int status_code);
// Bytes read notifications.
- void OnBytesRead(URLRequestJob* job, int byte_count);
+ void OnBytesRead(URLRequestJob* job, const char* buf, int byte_count);
// allows iteration over all active jobs
JobIterator begin() const {
« no previous file with comments | « net/url_request/url_request_job.cc ('k') | net/url_request/url_request_job_tracker.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698